==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/fa.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "گالری",
    "Could not load the description: " : "امکان بارگذاری توضیحات وجود ندارد:",
    "Copyright" : "کپی‌رایت",
    "New" : "جدید",
    "Error loading slideshow template" : "خطا در بارگذاری قالب نمایش به صورت اسلاید",
    "Next" : "بعدی",
    "Play" : "پخش کردن",
    "Pause" : "توقف کردن",
    "Previous" : "قبلی",
    "Close" : "بستن",
    "Download" : "دانلود",
    "Delete" : "حذف",
    "Share" : "اشتراک‌گذاری",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "Upload" : "بارگزاری",
    "Error" : "خطا",
    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
    "Error while unsharing" : "خطا درحال لغو اشتراک",
    "Error while changing permissions" : "خطا در حال تغییر مجوز",
    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
    "Share with users or groups …" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "Share with users, groups or remote users …" : "اشتراک گذاری با کاربران، گروه‌ها یا کاربران راه دور...",
    "Share link" : "اشتراک گذاشتن لینک",
    "The public link will expire no later than {days} days after it is created" : "لینک عمومی پس از {days} روز پس از ایجاد منقضی خواهد شد",
    "Link" : "لینک",
    "Password protect" : "نگهداری کردن رمز عبور",
    "Password" : "گذرواژه",
    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
    "Allow editing" : "اجازه‌ی ویرایش",
    "Email link to person" : "پیوند ایمیل برای شخص.",
    "Send" : "ارسال",
    "Set expiration date" : "تنظیم تاریخ انقضا",
    "Expiration" : "تاریخ انقضا",
    "Expiration date" : "تاریخ انقضا",
    "An error occured. Please try again" : "یک خطا رخ داده است، لطفا مجددا تلاش کنید",
    "Adding user..." : "افزودن کاربر...",
    "group" : "گروه",
    "remote" : "از راه دور",
    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
    "Unshare" : "لغو اشتراک",
    "notify by email" : "دریافت هشدار از طریق ایمیل",
    "can share" : "قابل به اشتراک گذاری",
    "can edit" : "می توان ویرایش کرد",
    "access control" : "کنترل دسترسی",
    "create" : "ایجاد",
    "change" : "تغییر",
    "delete" : "پاک کردن",
    "Password protected" : "نگهداری از رمز عبور",
    "Error unsetting expiration date" : "خطا در تنظیم نکردن تاریخ انقضا ",
    "Error setting expiration date" : "خطا در تنظیم تاریخ انقضا",
    "Sending ..." : "درحال ارسال ...",
    "Email sent" : "ایمیل ارسال شد",
    "Warning" : "اخطار",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
    "Sort by name" : "مرتب‌سازی بر اساس نام",
    "Sort by date" : "مرتب‌سازی بر اساس تاریخ",
    "Cancel upload" : "متوقف کردن بار گذاری",
    "Album information" : "اطلاعات آلبوم",
    "File list" : "لیست فایل ها",
    "Sorry, this file could not be found." : "متاسفم، این فایل یافت نشد.",
    "Reasons might be:" : "ممکن است به این دلایل باشد:",
    "the item was removed" : "این مورد حذف شده است",
    "the link has expired" : "لینک منقضی شده است",
    "sharing is disabled" : "قابلیت اشتراک گذاری غیرفعال است",
    "Picture view" : "نمایش تصویر",
    "Gallery view" : "نمایش گالری"
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/fa.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "گالری",
    "Could not load the description: " : "امکان بارگذاری توضیحات وجود ندارد:",
    "Copyright" : "کپی‌رایت",
    "New" : "جدید",
    "Error loading slideshow template" : "خطا در بارگذاری قالب نمایش به صورت اسلاید",
    "Next" : "بعدی",
    "Play" : "پخش کردن",
    "Pause" : "توقف کردن",
    "Previous" : "قبلی",
    "Close" : "بستن",
    "Download" : "دانلود",
    "Delete" : "حذف",
    "Share" : "اشتراک‌گذاری",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "Upload" : "بارگزاری",
    "Error" : "خطا",
    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
    "Error while unsharing" : "خطا درحال لغو اشتراک",
    "Error while changing permissions" : "خطا در حال تغییر مجوز",
    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
    "Share with users or groups …" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "Share with users, groups or remote users …" : "اشتراک گذاری با کاربران، گروه‌ها یا کاربران راه دور...",
    "Share link" : "اشتراک گذاشتن لینک",
    "The public link will expire no later than {days} days after it is created" : "لینک عمومی پس از {days} روز پس از ایجاد منقضی خواهد شد",
    "Link" : "لینک",
    "Password protect" : "نگهداری کردن رمز عبور",
    "Password" : "گذرواژه",
    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
    "Allow editing" : "اجازه‌ی ویرایش",
    "Email link to person" : "پیوند ایمیل برای شخص.",
    "Send" : "ارسال",
    "Set expiration date" : "تنظیم تاریخ انقضا",
    "Expiration" : "تاریخ انقضا",
    "Expiration date" : "تاریخ انقضا",
    "Adding user..." : "افزودن کاربر...",
    "group" : "گروه",
    "remote" : "از راه دور",
    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
    "Unshare" : "لغو اشتراک",
    "notify by email" : "دریافت هشدار از طریق ایمیل",
    "can share" : "قابل به اشتراک گذاری",
    "can edit" : "می توان ویرایش کرد",
    "access control" : "کنترل دسترسی",
    "create" : "ایجاد",
    "change" : "تغییر",
    "delete" : "پاک کردن",
    "Password protected" : "نگهداری از رمز عبور",
    "Error unsetting expiration date" : "خطا در تنظیم نکردن تاریخ انقضا ",
    "Error setting expiration date" : "خطا در تنظیم تاریخ انقضا",
    "Email sent" : "ایمیل ارسال شد",
    "Warning" : "اخطار",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
    "Sort by name" : "مرتب‌سازی بر اساس نام",
    "Sort by date" : "مرتب‌سازی بر اساس تاریخ",
    "Cancel upload" : "متوقف کردن بار گذاری",
    "Album information" : "اطلاعات آلبوم",
    "File list" : "لیست فایل ها",
    "Sorry, this file could not be found." : "متاسفم، این فایل یافت نشد.",
    "Reasons might be:" : "ممکن است به این دلایل باشد:",
    "the item was removed" : "این مورد حذف شده است",
    "the link has expired" : "لینک منقضی شده است",
    "sharing is disabled" : "قابلیت اشتراک گذاری غیرفعال است",
    "Picture view" : "نمایش تصویر",
    "Gallery view" : "نمایش گالری",
    "An error occured. Please try again" : "یک خطا رخ داده است، لطفا مجددا تلاش کنید",
    "Sending ..." : "درحال ارسال ..."
},
"nplurals=1; plural=0;");
